netapp_ontap.models.cluster_nodes_ha API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cluster_nodes_ha`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ClusterNodesHaSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ClusterNodesHa object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `auto_giveback: bool GET POST PATCH`

    Specifies whether giveback is automatically initiated when the node that owns the storage is ready.

  `auto_giveback_of: bool GET POST PATCH`

    Specifies whether giveback is automatically initiated when the node that owns the storage is ready.

  `enable_takeover_of: bool GET`

    Specifies whether or not storage failover is enabled.

  `enabled: bool GET POST PATCH`

    Specifies whether or not storage failover is enabled.

  `giveback: ClusterNodesHaGiveback GET`

    Represents the state of the node that is giving storage back to its HA partner.

  `interconnect: ClusterNodesHaInterconnect GET`

    The interconnect field of the cluster_nodes_ha.

  `partners: List[Node] GET`

    Nodes in this node's High Availability (HA) group.

  `ports: List[ClusterNodesHaPorts] GET`

    The ports field of the cluster_nodes_ha.

  `takeover: ClusterNodesHaTakeover GET`

    This represents the state of the node that is taking over storage from its HA partner.

  `takeover_check: ClusterNodesHaTakeoverCheck GET`

    The takeover check response.

  `type: str GET`

    Type of storage.

    Valid choices:

    - shared_storage
    - non_shared_storage